==> kitlist_0.6.6.tar.gz: kitlist-0.6.6/autogen.sh <==
#! /bin/sh

# $Id: autogen.sh,v 1.6 2004/06/10 16:51:21 daniel Exp $
#
# Copyright (c) 2002  Daniel Elstner  <daniel.elstner@gmx.net>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License VERSION 2 as
# published by the Free Software Foundation.  You are not allowed to
# use any other version of the license; unless you got the explicit
# permission from the author to do so.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


dir=`echo "$0" | sed 's,[^/]*$,,'`
test "x${dir}" = "x" && dir='.'

if test "x`cd "${dir}" 2>/dev/null && pwd`" != "x`pwd`"
then
    echo "This script must be executed directly from the source directory."
    exit 1
fi

rm -f config.cache acconfig.h

echo "- glib-gettextize."	&& \
glib-gettextize --force --copy	&& \
echo "- libtoolize." && \
libtoolize --automake && \
echo "- intltoolize." && \
intltoolize --copy --force --automake && \
echo "- aclocal."		&& \
aclocal $ACLOCAL_FLAGS	&& \
echo "- autoconf."		&& \
autoconf			&& \
echo "- autoheader."		&& \
autoheader			&& \
echo "- automake."		&& \
automake --add-missing --gnu && \
echo				&& \
./configure "$@"		&& exit 0

exit 1

==> kitlist_1.0.0.orig.tar.gz: kitlist-1.0.0/autogen.sh <==
#! /bin/sh

# $Id: autogen.sh,v 1.6 2004/06/10 16:51:21 daniel Exp $
#
# Copyright (c) 2002  Daniel Elstner  <daniel.elstner@gmx.net>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License VERSION 2 as
# published by the Free Software Foundation.  You are not allowed to
# use any other version of the license; unless you got the explicit
# permission from the author to do so.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


dir=`echo "$0" | sed 's,[^/]*$,,'`
test "x${dir}" = "x" && dir='.'

if test "x`cd "${dir}" 2>/dev/null && pwd`" != "x`pwd`"
then
    echo "This script must be executed directly from the source directory."
    exit 1
fi

rm -f config.cache acconfig.h

LIBTOOLIZE=libtoolize
# Mac OS X uses glibtoolize
if which glibtoolize >/dev/null; then
    LIBTOOLIZE=glibtoolize
fi

echo "- glib-gettextize."	&& \
glib-gettextize --force --copy	&& \
echo "- $LIBTOOLIZE." && \
$LIBTOOLIZE --automake && \
echo "- intltoolize." && \
intltoolize --copy --force --automake && \
echo "- aclocal."		&& \
aclocal $ACLOCAL_FLAGS	&& \
echo "- autoconf."		&& \
autoconf			&& \
echo "- autoheader."		&& \
autoheader			&& \
echo "- automake."		&& \
automake --add-missing --gnu && \
echo				&& \
./configure "$@"		&& exit 0

exit 1
